
# THIS FILE IS GENERATED FROM WEAVE SETUP.PY
short_version = '0.17.0'
version = '0.17.0'
full_version = '0.17.0'
git_revision = '55d48df39b9685164a71fd29050ad45d307b0a97'
release = True

if not release:
    version = full_version
