



REG ADD HKLM\SYSTEM\CurrentControlSet\Control\FileSystem /v LongPathsEnabled /d 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
python -c "import weave;assert weave.inline('int x=42; return_val=x;') == 42"
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
